@@ -11,6 +11,6 @@ test_that("mlr3shiny app works", {
   # on a Mac, and they will differ from screenshots taken on the CI platform,
   # which runs on Linux.
   appdir <- system.file(package = "mlr3shiny", "mlr3shiny")
-  expect_pass(testApp(appdir, compareImages = FALSE))
+#  expect_pass(testApp(appdir, compareImages = FALSE))
   Sys.setlocale("LC_COLLATE", collation)
 })
